@@ -303,7 +303,7 @@ void AutoCorrectionSettings::setTwoUpperLetterExceptions(const QSet<QString> &ex
     d->mTwoUpperLetterExceptions = exceptions;
 }
 
-QSet<QString> AutoCorrectionSettings::upperCaseExceptions() const
+const QSet<QString> &AutoCorrectionSettings::upperCaseExceptions() const
 {
     return d->mUpperCaseExceptions;
 }
@@ -453,67 +453,6 @@ void AutoCorrectionSettings::loadGlobalFileName(const QString &fname)
     }
 }
 
-void AutoCorrectionSettings::migrateKMailXmlFile()
-{
-#if 0
-    // TODO
-    QString kdelang = QStringLiteral("en_US");
-    const QStringList lst = QLocale::system().uiLanguages();
-    if (!lst.isEmpty()) {
-        kdelang = lst.at(0);
-        if (kdelang == QLatin1Char('C')) {
-            kdelang = QStringLiteral("en_US");
-        }
-    }
-    static QRegularExpression reg(QStringLiteral("@.*"));
-    kdelang.remove(reg);
-
-    QString localFileName;
-    static QRegularExpression regpath(QRegularExpression(QStringLiteral("_.*")));
-    // Look at local file:
-    if (!forceGlobal) {
-        if (!mAutoCorrectLang.isEmpty()) {
-            localFileName =
-                QStandardPaths::locate(QStandardPaths::GenericDataLocation, "autocorrect/custom-"_L1 + mAutoCorrectLang + ".xml"_L1);
-        } else {
-            if (!kdelang.isEmpty()) {
-                localFileName =
-                    QStandardPaths::locate(QStandardPaths::GenericDataLocation, "autocorrect/custom-"_L1 + kdelang + ".xml"_L1);
-            }
-            if (localFileName.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
-                kdelang.remove(regpath);
-                localFileName =
-                    QStandardPaths::locate(QStandardPaths::GenericDataLocation, "autocorrect/custom-"_L1 + kdelang + ".xml"_L1);
-            }
-        }
-    }
-    QString fname;
-    // Load Global directly
-    if (!mAutoCorrectLang.isEmpty()) {
-        if (mAutoCorrectLang == "en_US"_L1) {
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/autocorrect.xml"));
-        } else {
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "autocorrect/"_L1 + mAutoCorrectLang + ".xml"_L1);
-        }
-    } else {
-        if (fname.isEmpty() && !kdelang.isEmpty()) {
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "autocorrect/"_L1 + kdelang + ".xml"_L1);
-        }
-        if (fname.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
-            kdelang.remove(regpath);
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "autocorrect/"_L1 + kdelang + ".xml"_L1);
-        }
-    }
-    if (fname.isEmpty()) {
-        fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/autocorrect.xml"));
-    }
-
-    if (mAutoCorrectLang.isEmpty()) {
-        mAutoCorrectLang = kdelang;
-    }
-#endif
-}
-
 void AutoCorrectionSettings::readAutoCorrectionFile(bool forceGlobal)
 {
     d->mUpperCaseExceptions.clear();
@@ -521,26 +460,26 @@ void AutoCorrectionSettings::readAutoCorrectionFile(bool forceGlobal)
     d->mTwoUpperLetterExceptions.clear();
     d->mSuperScriptEntries.clear();
 
-    QString kdelang = QStringLiteral("en-US");
+    QString kdelang = u"en-US"_s;
     const QStringList lst = QLocale::system().uiLanguages();
     if (!lst.isEmpty()) {
         kdelang = lst.at(0);
-        if (kdelang == QLatin1Char('C')) {
-            kdelang = QStringLiteral("en-US");
+        if (kdelang == u'C') {
+            kdelang = u"en-US"_s;
         }
     }
-    static QRegularExpression reg(QStringLiteral("@.*"));
+    static QRegularExpression reg(u"@.*"_s);
     kdelang.remove(reg);
 
     QString localFileName;
-    static QRegularExpression regpath(QRegularExpression(QStringLiteral("_.*")));
+    static QRegularExpression regpath(QRegularExpression(u"_.*"_s));
     // Look at local file:
     if (!forceGlobal) {
         if (d->mAutoCorrectLang.isEmpty()) {
             if (!kdelang.isEmpty()) {
                 localFileName = containsAutoCorrectionFile(kdelang);
             }
-            if (localFileName.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
+            if (localFileName.isEmpty() && kdelang.contains(u'_')) {
                 kdelang.remove(regpath);
                 localFileName = containsAutoCorrectionFile(kdelang);
             }
@@ -554,7 +493,7 @@ void AutoCorrectionSettings::readAutoCorrectionFile(bool forceGlobal)
         if (fname.isEmpty() && !kdelang.isEmpty()) {
             fname = containsAutoCorrectionFile(kdelang);
         }
-        if (fname.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
+        if (fname.isEmpty() && kdelang.contains(u'_')) {
             kdelang.remove(regpath);
             fname = containsAutoCorrectionFile(kdelang);
         }
