@@ -5,6 +5,8 @@
 */
 
 #include "autocorrectionwidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "autocorrectionutils.h"
 
 #include "ui_autocorrectionwidget.h"
@@ -463,7 +465,7 @@ void AutoCorrectionWidget::removeAutocorrectEntry()
         return;
     }
     for (QTreeWidgetItem *item : listItems) {
-        QTreeWidgetItem *below = d->ui->treeWidget->itemBelow(item);
+        const QTreeWidgetItem *below = d->ui->treeWidget->itemBelow(item);
 
         QString findStr;
         if (below) {
