@@ -4,6 +4,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ollamamodelinstalledinfowidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ollamamodelflowlayout.h"
 #include <KLocalizedString>
 #include <QGroupBox>
@@ -18,42 +20,42 @@ OllamaModelInstalledInfoWidget::OllamaModelInstalledInfoWidget(QWidget *parent)
     , mModifiedAtLabel(new QLabel(this))
     , mMainLayout(new QVBoxLayout(this))
 {
-    mMainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mMainLayout->setObjectName(u"mainLayout"_s);
 
     {
         auto label = new QLabel(i18n("Family:"), this);
-        mMainLayout->addWidget(label);
+        mMainLayout->addWidget(label, 0, Qt::AlignTop);
         changeFont(label);
 
-        mFamilyNameLabel->setObjectName(QStringLiteral("mFamilyNameLabel"));
-        mMainLayout->addWidget(mFamilyNameLabel);
+        mFamilyNameLabel->setObjectName(u"mFamilyNameLabel"_s);
+        mMainLayout->addWidget(mFamilyNameLabel, 0, Qt::AlignTop);
     }
 
     {
         auto label = new QLabel(i18n("Parameter Size:"), this);
-        mMainLayout->addWidget(label);
+        mMainLayout->addWidget(label, 0, Qt::AlignTop);
         changeFont(label);
 
-        mParameterSizeLabel->setObjectName(QStringLiteral("mParameterSizeLabel"));
-        mMainLayout->addWidget(mParameterSizeLabel);
+        mParameterSizeLabel->setObjectName(u"mParameterSizeLabel"_s);
+        mMainLayout->addWidget(mParameterSizeLabel, 0, Qt::AlignTop);
     }
 
     {
         auto label = new QLabel(i18n("Quantization Level:"), this);
-        mMainLayout->addWidget(label);
+        mMainLayout->addWidget(label, 0, Qt::AlignTop);
         changeFont(label);
 
-        mQuantizationLevelLabel->setObjectName(QStringLiteral("mQuantizationLevelLabel"));
-        mMainLayout->addWidget(mQuantizationLevelLabel);
+        mQuantizationLevelLabel->setObjectName(u"mQuantizationLevelLabel"_s);
+        mMainLayout->addWidget(mQuantizationLevelLabel, 0, Qt::AlignTop);
     }
 
     {
         auto label = new QLabel(i18n("Modified At:"), this);
-        mMainLayout->addWidget(label);
+        mMainLayout->addWidget(label, 0, Qt::AlignTop);
         changeFont(label);
 
-        mModifiedAtLabel->setObjectName(QStringLiteral("mModifiedAtLabel"));
-        mMainLayout->addWidget(mModifiedAtLabel);
+        mModifiedAtLabel->setObjectName(u"mModifiedAtLabel"_s);
+        mMainLayout->addWidget(mModifiedAtLabel, 0, Qt::AlignTop);
     }
 }
 
@@ -82,8 +84,17 @@ void OllamaModelInstalledInfoWidget::setOllamaModelInstalledInfo(const OllamaMod
     auto infoLayout = new QVBoxLayout(mInfoWidget);
     infoLayout->setContentsMargins({});
 
+    if (const QString parentModelName = info.parentModel(); !parentModelName.isEmpty()) {
+        auto label = new QLabel(i18n("Parent Model:"), mInfoWidget);
+        infoLayout->addWidget(label);
+        changeFont(label);
+
+        auto parentModelLabel = new QLabel(parentModelName, mInfoWidget);
+        infoLayout->addWidget(parentModelLabel);
+    }
+
     QString installedName = info.model();
-    const int position = installedName.indexOf(QLatin1Char(':'));
+    const int position = installedName.indexOf(u':');
     installedName = installedName.first(position);
     auto matchesModelName = [&](const OllamaModelAvailableInfo &availableInfo) {
         return availableInfo.name() == installedName;
@@ -97,15 +108,34 @@ void OllamaModelInstalledInfoWidget::setOllamaModelInstalledInfo(const OllamaMod
             const QLocale locale(lang);
             vboxLanguagesLayout->addWidget(new QLabel(QLocale::languageToString(locale.language()), mInfoWidget));
         }
-        auto featuresGroupBox = new QGroupBox(i18n("Features Supported"), mInfoWidget);
-        infoLayout->addWidget(featuresGroupBox);
-        auto vboxfeaturesLayout = new OllamaModelFlowLayout(featuresGroupBox);
-        for (const auto &cat : (*it).categoriesName()) {
-            vboxfeaturesLayout->addWidget(new QLabel(cat, mInfoWidget));
+
+        QStringList categoriesName;
+        const OllamaModelAvailableInfo::Categories categories = (*it).categories();
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Tools, categories);
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Multilingual, categories);
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Code, categories);
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Math, categories);
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Vision, categories);
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Embedding, categories);
+        appendCategories(categoriesName, OllamaModelAvailableInfo::Category::Reasoning, categories);
+        if (!categoriesName.isEmpty()) {
+            auto featuresGroupBox = new QGroupBox(i18n("Features Supported"), mInfoWidget);
+            infoLayout->addWidget(featuresGroupBox);
+            auto vboxfeaturesLayout = new OllamaModelFlowLayout(featuresGroupBox);
+            for (const QString &name : categoriesName) {
+                vboxfeaturesLayout->addWidget(new QLabel(name, mInfoWidget));
+            }
         }
     }
 
     infoLayout->addStretch(1);
 }
 
+void OllamaModelInstalledInfoWidget::appendCategories(QStringList &lst, OllamaModelAvailableInfo::Category cat, OllamaModelAvailableInfo::Categories categories)
+{
+    if (categories & cat) {
+        lst.append(OllamaModelAvailableInfo::convertCategoryToI18n(cat));
+    }
+}
+
 #include "moc_ollamamodelinstalledinfowidget.cpp"
