@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,7 +38,7 @@ TranslatorDebugDialog::TranslatorDebugDialog(QWidget *parent)
     buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &TranslatorDebugDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TranslatorDebugDialog::reject);
-    mUser1Button->setText(i18n("Save As..."));
+    mUser1Button->setText(i18n("Save As…"));
     connect(mUser1Button, &QPushButton::clicked, this, &TranslatorDebugDialog::slotSaveAs);
 
     mEdit->setReadOnly(true);
@@ -64,14 +64,14 @@ void TranslatorDebugDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(800, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myTranslatorDebugDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myTranslatorDebugDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void TranslatorDebugDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myTranslatorDebugDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myTranslatorDebugDialogConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
@@ -91,7 +91,7 @@ void TranslatorDebugDialog::saveTextAs(const QString &text, const QString &filte
                                     "\"%2\" is the detailed error description.",
                                     fileName,
                                     QString::fromLocal8Bit(strerror(errno))),
-                               i18n("Save File Error"));
+                               i18nc("@title:window", "Save File Error"));
         }
     }
     delete fdlg;
@@ -104,9 +104,6 @@ bool TranslatorDebugDialog::saveToFile(const QString &filename, const QString &t
         return false;
     }
     QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    out.setCodec("UTF-8");
-#endif
     out << text;
     file.close();
     return true;
